# hestonpy

`hestonpy` is now avalaible on PyPi !
```bash
pip install hestonpy
```

The `hestonpy` Python package implements the Heston and Black-Scholes models for option pricing and portfolio management. The package also includes functionality for optimal portfolio allocation using stochastic control techniques.

Covered topics by the `hestonpy` package [TO DO: calibration on iv surface + SVJ simulations/monte carlo]:
1. path simulations
2. pricing plain european vanilla options
3. model calibration (smile) from yahoo finance and personnal data
4. SVI implementation
5. asset allocations (stochastic optimal control under Heston dynamics)

## License

`hestonpy` was created by Théophile SCHMUTZ (@SarcasticMatrix). It is licensed under the terms of the MIT license.